"use strict";

// src/index.ts
var import_language_service2 = require("@vtsls/language-service");
var import_node2 = require("vscode-languageserver/node");
var import_vscode_uri = require("vscode-uri");

// src/capabilities.ts
var import_language_service = require("@vtsls/language-service");
var import_node = require("vscode-languageserver/node");
function getTsLspDefaultCapabilities() {
  return {
    textDocumentSync: {
      openClose: true,
      change: import_node.TextDocumentSyncKind.Incremental,
      willSave: false,
      willSaveWaitUntil: false,
      save: false
    },
    completionProvider: {
      triggerCharacters: import_language_service.completionTriggerCharacters,
      resolveProvider: true,
      completionItem: {
        labelDetailsSupport: true
      }
    },
    hoverProvider: true,
    signatureHelpProvider: {
      triggerCharacters: import_language_service.signatureHelpTriggerCharacters,
      retriggerCharacters: import_language_service.signatureHelpReTriggerCharacters
    },
    declarationProvider: false,
    definitionProvider: true,
    typeDefinitionProvider: true,
    implementationProvider: true,
    referencesProvider: true,
    documentHighlightProvider: true,
    documentSymbolProvider: {
      label: "typescript"
    },
    codeActionProvider: {
      codeActionKinds: import_language_service.codeActionKinds,
      resolveProvider: true
    },
    codeLensProvider: { resolveProvider: true },
    documentLinkProvider: void 0,
    colorProvider: false,
    workspaceSymbolProvider: { resolveProvider: false },
    documentFormattingProvider: true,
    documentRangeFormattingProvider: true,
    documentOnTypeFormattingProvider: {
      firstTriggerCharacter: import_language_service.onTypeFormatFirstTriggerCharacter,
      moreTriggerCharacter: import_language_service.onTypeFormatMoreTriggerCharacter
    },
    renameProvider: {
      prepareProvider: true
    },
    foldingRangeProvider: true,
    selectionRangeProvider: true,
    executeCommandProvider: {
      commands: import_language_service.commands
    },
    callHierarchyProvider: true,
    linkedEditingRangeProvider: false,
    semanticTokensProvider: {
      legend: {
        tokenTypes: import_language_service.semanticTokenTypes,
        tokenModifiers: import_language_service.semanticTokenModifiers
      },
      full: false,
      range: true
    },
    monikerProvider: false,
    typeHierarchyProvider: false,
    inlineValueProvider: false,
    inlayHintProvider: true,
    diagnosticProvider: {
      identifier: "typescript",
      interFileDependencies: true,
      workspaceDiagnostics: false
    },
    workspace: {
      workspaceFolders: {
        supported: true,
        changeNotifications: true
      },
      fileOperations: {
        didRename: {
          filters: [
            {
              scheme: "file",
              pattern: {
                glob: "**/*.{ts,tsx,js,jsx}",
                matches: "file"
              }
            }
          ]
        }
      }
    }
  };
}

// src/index.ts
function createLanguageServer() {
  const conn = (0, import_node2.createConnection)(import_node2.ProposedFeatures.all);
  conn.onInitialize((params) => {
    return onServerInitialize(conn, params);
  });
  conn.listen();
}
function onServerInitialize(conn, params) {
  const clientCapabilities = params.capabilities;
  const root = params.rootUri ?? (params.rootPath ? import_vscode_uri.URI.file(params.rootPath).toString() : void 0);
  const folders = params.workspaceFolders ?? (typeof root == "string" ? [{ name: root, uri: root }] : void 0);
  const service = (0, import_language_service2.createTSLanguageService)({
    locale: params.locale,
    workspaceFolders: folders,
    clientCapabilities
  });
  async function initializeService() {
    void conn.sendRequest(import_node2.ConfigurationRequest.type, { items: [{}] }).then((config) => {
      if (Array.isArray(config)) {
        void service.initialize(config[0]);
      }
    });
    try {
      await service.initialized.wait();
    } catch (e) {
      conn.dispose();
    }
  }
  conn.onInitialized(() => {
    bindServiceHandlers(conn, service);
    void initializeService();
  });
  return {
    capabilities: getTsLspDefaultCapabilities(),
    serverInfo: { name: "vtsls", version: "0.1.5" }
  };
}
function bindServiceHandlers(conn, service) {
  service.onLogMessage(
    (params) => void conn.sendNotification(import_node2.LogMessageNotification.method, params)
  );
  service.onShowMessage((params) => conn.sendRequest(import_node2.ShowMessageRequest.type, params));
  service.onShowDocument(
    async (params) => (await conn.sendRequest(import_node2.ShowDocumentRequest.type, params)).success
  );
  service.onWorkDoneProgress(() => conn.window.createWorkDoneProgress());
  service.onApplyWorkspaceEdit((params) => conn.workspace.applyEdit(params));
  service.onDiagnostics((params) => conn.sendDiagnostics(params));
  conn.onExit(() => service.dispose());
  conn.onShutdown(() => service.dispose());
  conn.onDidOpenTextDocument(service.openTextDocument);
  conn.onDidCloseTextDocument(service.closeTextDocument);
  conn.onDidChangeTextDocument(service.changeTextDocument);
  conn.onDidChangeConfiguration(service.changeConfiguration);
  conn.workspace.onDidRenameFiles(service.renameFiles);
  conn.workspace.onDidChangeWorkspaceFolders((event) => service.changeWorkspaceFolders({ event }));
  conn.onCompletion(service.completion);
  conn.onCompletionResolve(service.completionItemResolve);
  conn.onDocumentHighlight(service.documentHighlight);
  conn.onSignatureHelp(service.signatureHelp);
  conn.onDefinition(service.definition);
  conn.onReferences(service.references);
  conn.onHover(service.hover);
  conn.onDocumentSymbol(service.documentSymbol);
  conn.onWorkspaceSymbol(service.workspaceSymbol);
  conn.onCodeAction(service.codeAction);
  conn.onCodeActionResolve(service.codeActionResolve);
  conn.onExecuteCommand(service.executeCommand);
  conn.onImplementation(service.implementation);
  conn.onTypeDefinition(service.typeDefinition);
  conn.onDocumentFormatting(service.documentFormatting);
  conn.onDocumentRangeFormatting(service.documentRangeFormatting);
  conn.onDocumentOnTypeFormatting(service.documentOnTypeFormatting);
  conn.onPrepareRename(service.prepareRename);
  conn.onRenameRequest(service.rename);
  conn.onFoldingRanges(service.foldingRanges);
  conn.onSelectionRanges(service.selectionRanges);
  conn.onCodeLens(service.codeLens);
  conn.onCodeLensResolve(service.codeLensResolve);
  conn.languages.callHierarchy.onPrepare(service.prepareCallHierachy);
  conn.languages.callHierarchy.onIncomingCalls(service.incomingCalls);
  conn.languages.callHierarchy.onOutgoingCalls(service.outgoingCalls);
  conn.languages.inlayHint.on(service.inlayHint);
  conn.languages.semanticTokens.onRange(service.semanticTokensRange);
}
createLanguageServer();
